import { useState, useEffect, useRef } from 'react';
import { Menu, X } from 'lucide-react';

// 定义菜单项和对应的URL哈希值
interface MenuItem {
  name: string;
  hash: string;
  id: string;
}

export default function Navbar() {
  const [isScrolled, setIsScrolled] = useState(false);
  const [isMenuOpen, setIsMenuOpen] = useState(false);
  const [activeHash, setActiveHash] = useState('');
  const autoCloseTimerRef = useRef<ReturnType<typeof setTimeout>>();
  const menuRef = useRef<HTMLDivElement>(null);
  const menuToggleBtnRef = useRef<HTMLButtonElement>(null);

  // 菜单项配置
  const menuItems: MenuItem[] = [
    { name: '首页', hash: '#home', id: '首页' },
    { name: '关于我们', hash: '#about', id: '关于我们' },
    { name: '核心业务', hash: '#business', id: '核心业务' },
    { name: '量子基金', hash: '#fund', id: '量子基金' },
    { name: '人才招聘', hash: '#careers', id: '人才招聘' },
    { name: '联系我们', hash: '#contact', id: '联系我们' }
  ];

  useEffect(() => {
    const handleScroll = () => {
      setIsScrolled(window.scrollY > 50);

      // 滚动时检测当前视图中的部分，更新活动哈希
      const scrollPosition = window.scrollY + 100; // 添加偏移量，考虑导航栏高度
      
      // 找到当前在视图中的所有部分
      const sections = menuItems.map(item => {
        const element = document.getElementById(item.id);
        if (!element) return null;
        
        const rect = element.getBoundingClientRect();
        const top = rect.top + window.pageYOffset;
        return { id: item.id, top, hash: item.hash };
      }).filter(Boolean);
      
      // 根据滚动位置确定当前部分
      let currentSection = sections[0];
      for (const section of sections) {
        if (section && section.top <= scrollPosition) {
          currentSection = section;
        } else {
          break;
        }
      }
      
      if (currentSection && currentSection.hash !== activeHash) {
        setActiveHash(currentSection.hash);
        // 仅在用户手动滚动时更新URL（不是通过点击菜单）
        if (!window.location.hash || window.location.hash !== currentSection.hash) {
          window.history.replaceState(null, '', currentSection.hash);
        }
      }
    };
    
    window.addEventListener('scroll', handleScroll);
    return () => window.removeEventListener('scroll', handleScroll);
  }, [activeHash, menuItems]);

  useEffect(() => {
    const handleClickOutside = (event: MouseEvent | TouchEvent) => {
      if (menuToggleBtnRef.current && menuToggleBtnRef.current.contains(event.target as Node)) {
        return;
      }
      if (menuRef.current && !menuRef.current.contains(event.target as Node)) {
        console.log('Navbar: Clicked outside menu panel, closing menu.');
        setIsMenuOpen(false);
      }
    };

    if (isMenuOpen) {
      document.addEventListener('mousedown', handleClickOutside);
      document.addEventListener('touchstart', handleClickOutside);
    }

    return () => {
      document.removeEventListener('mousedown', handleClickOutside);
      document.removeEventListener('touchstart', handleClickOutside);
    };
  }, [isMenuOpen]);

  useEffect(() => {
    if (isMenuOpen) {
      if (autoCloseTimerRef.current) {
        clearTimeout(autoCloseTimerRef.current);
      }
      autoCloseTimerRef.current = setTimeout(() => {
        console.log('Navbar: Auto-closing menu after 3 seconds.');
        setIsMenuOpen(false);
      }, 3000);
    }
    return () => {
      if (autoCloseTimerRef.current) {
        clearTimeout(autoCloseTimerRef.current);
      }
    };
  }, [isMenuOpen]);

  const scrollToSection = (hash: string, id: string) => {
    const element = document.getElementById(id);
    if (element) {
      const navHeight = 64;
      const elementPosition = element.getBoundingClientRect().top;
      const offsetPosition = elementPosition + window.pageYOffset - navHeight;
      
      // 更新URL哈希但不触发滚动（使用replaceState而不是设置location.hash）
      window.history.pushState(null, '', hash);
      setActiveHash(hash);
      
      // 然后手动滚动
      window.scrollTo({
        top: offsetPosition,
        behavior: 'smooth'
      });
      console.log('Navbar: Scrolling to section, closing menu.');
      setIsMenuOpen(false);
    }
  };

  return (
    <nav 
      className={`fixed top-0 left-0 right-0 z-50 transition-all duration-500 ${
        isScrolled || isMenuOpen ? 'bg-[#0a0a1a]/60 backdrop-blur-lg shadow-lg' : 'bg-transparent'
      }`}
    >
      <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
        <div className="flex items-center justify-between h-16 md:h-20">
          <div className="flex-shrink-0">
            <a 
              href="#home"
              onClick={(e) => {
                e.preventDefault();
                scrollToSection('#home', '首页');
              }}
              className="block"
            >
              <img 
                src="/images/logo.png"
                alt="Quantum Logo"
                className="h-10 md:h-12 w-auto hover:opacity-80 transition-opacity"
              />
            </a>
          </div>

          <div className="hidden md:flex items-center space-x-1">
            {menuItems.map((item) => (
              <a
                key={item.name}
                href={item.hash}
                onClick={(e) => {
                  e.preventDefault();
                  scrollToSection(item.hash, item.id);
                }}
                className={`relative px-4 py-2 group ${
                  activeHash === item.hash ? 'text-white' : 'text-white/70'
                }`}
              >
                <span className={`relative z-10 text-base font-medium transition-colors duration-300 ${
                  activeHash === item.hash ? 'text-white' : 'text-white/70 group-hover:text-white'
                }`}>
                  {item.name}
                </span>
                <div className="absolute inset-0 bg-white/0 group-hover:bg-white/5 rounded-lg transition-colors duration-300"></div>
                <div className={`absolute bottom-0 left-1/2 -translate-x-1/2 h-0.5 bg-gradient-to-r from-blue-400 to-cyan-400 transition-all duration-300 ${
                  activeHash === item.hash ? 'w-full' : 'w-0 group-hover:w-full'
                }`}></div>
              </a>
            ))}
          </div>

          <div className="md:hidden">
            <button
              ref={menuToggleBtnRef}
              onClick={() => {
                console.log('Navbar: Toggle button clicked. Current isMenuOpen:', isMenuOpen, 'Will be set to:', !isMenuOpen);
                setIsMenuOpen(!isMenuOpen);
              }}
              className="relative w-8 h-8 flex items-center justify-center"
              aria-label="Toggle menu"
            >
              <div className="absolute inset-0 bg-white/5 rounded-lg transition-colors hover:bg-white/10"></div>
              {isMenuOpen ? (
                <X className="w-4 h-4 text-white/70" />
              ) : (
                <Menu className="w-4 h-4 text-white/70" />
              )}
            </button>
          </div>
        </div>
      </div>

      <div 
        ref={menuRef}
        className={`md:hidden fixed inset-x-0 top-16 transition-all duration-300 ${
          isMenuOpen ? 'opacity-100 translate-y-0 pointer-events-auto' : 'opacity-0 -translate-y-4 pointer-events-none'
        }`}
        style={{ maxHeight: 'calc(100vh - 4rem)', overflowY: 'auto' }}
      >
        <div className="p-4 space-y-2 bg-black/60 backdrop-blur-lg">
          {menuItems.map((item) => (
            <a
              key={item.name}
              href={item.hash}
              onClick={(e) => {
                e.preventDefault();
                scrollToSection(item.hash, item.id);
              }}
              className={`block px-4 py-3 text-base font-medium transition-all duration-300 ${
                activeHash === item.hash 
                  ? 'text-white bg-white/5' 
                  : 'text-white/70 hover:text-white hover:bg-white/5 active:bg-white/10 active:scale-95'
              } rounded-lg`}
            >
              {item.name}
            </a>
          ))}
        </div>
      </div>
    </nav>
  );
}